window.Gleam.initSearch([{"doc":"bg_jobs","title":"bg_jobs","content":"# bg_jobs - Background job processing for your Gleam app\n[![Package Version](https://img.shields.io/hexpm/v/bg_jobs)](https://hex.pm/packages/bg_jobs)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/bg_jobs/)\n\n# TODO before version 1\nFeel free to contribute if you want to move the project forward. My time working\non this is limited.\n- [ ] Generally improve documentation\n- [ ] Split db adapters to their own packages\n  - To do this testing needs change since the tests depend on the sqlite adapter\n- [ ] In the monitor module, `release abandoned jobs` should run on an interval to\n  handle the case where the down message is not received \n\n### Other improvements\n- [ ] Mock time implementation to not have to sleep in tests\n\n# Docs are WIP right now\nMost of it is correct but not complete, some parts are duplicated.\n\n# What is bg_jobs\nWhen developing web applications, certain tasks, like processing large files or \nperforming heavy calculations can slow down regular request handling. \nbg_jobs helps by moving these time-consuming operations to a background \nqueue, keeping your application responsive.\n\nThis library is SQL-driven, with adapters for sqlite and postgres included. \nSo you don’t need extra dependencies to get background processing up \nand running. Just connect to your existing database, set up your \nbackground jobs, and your app can handle more demanding tasks without \nimpacting user experience.\n\nBg_jobs provide the following:\n- *Queues* - including delayed execution\n- *Scheduled jobs* - on an interval or cron like schedule\n\n\n# Time and date\nAll dates should be passed in UTC+0\n\n# Installation \n\n```sh\ngleam add bg_jobs\n```\n# Example usage \nA complete example setup can be found in the /example directory.\n```gleam\nimport bg_jobs\nimport bg_jobs/job\nimport bg_jobs/queue\nimport gleam/otp/static_supervisor\n\nfn example_worker() { \n  jobs.Worker(job_name: &quot;example_job&quot;, handler: fn(job: jobs.Job) {\n      io.print(job.payload)\n  })\n}\n\npub fn main() {\n  let conn = todo as &quot;the sqlight connection&quot;\n\n  let bg = \n    static_supervisor.new(static_supervisor.OneForOne)\n    |&gt; bg_jobs.new(sqlite_db_adapter.new(conn, []))\n    |&gt; bg_jobs.with_queue(\n      queue.new(&quot;default_queue&quot;)\n      |&gt; queue.with_worker(example_worker())\n    )\n    |&gt; bg_jobs.build()\n\n  // Dispatch a new job\n  jobs.new(example_worker.job_name, &quot;Hello!&quot;))\n  |&gt; bg_jobs.enqueue(bg)\n\n  process.sleep_forever()\n}\n```\nThis example sets up a `default_queue` to handle `example_worker` jobs. \nWhen a job with the payload &quot;Hello!&quot; is dispatched, it is stored in the \ndatabase, picked up by the queue, and logged.\n\n# Architecture\n*TODO:* expand this section\n\nProgram architecture:\n- *otp supervisor*\n  - *otp worker* - queue (0 or more)\n    - Polls the database on specified interval looking for avaliable jobs of the type it can handle\n  - *otp worker* - scheduled jobs queue (0 or more)\n    - Polls the database on specified interval looking for avaliable jobs of the type it can handle\n    - Enqueus a new job with apropriate avalible at after processing is done \n  - *otp worker* - monitor (1 per program)\n    - Holds Subjects to all workers in bg_jobs. This is used for named lookup\n\n## Durability\nTODO: update, this is not exactly correct any more..\n~~Jobs are claimed with a timestamp and queue/scheduled job name.\nEach queue and scheduled job should have a unique name even across machines.\nWhenever the worker starts up it clears out previously claimed jobs.\nThis way if a worker crashes and the supervisor restarts it there is no \nabandoned jobs.~~\n\n\n# Supervisor Integration in bg_jobs\n\nbg_jobs is an OTP-based job scheduling system that integrates with \nErlang’s supervision tree. When setting up bg_jobs, you need to pass \na `static_supervisor.Builder` along with a db_adapter. This provides \nflexibility, allowing you to configure the supervisor&#39;s settings \nbefore passing it into bg_jobs. You can also choose to supervise the \ncreated supervisor itself.\n\n## Configuring the Supervisor for bg_jobs\n\nTo set custom parameters for the bg_jobs supervisor, you need to \nfirst create the supervisor with the desired strategy and \nconfiguration settings. \n\n**Example 1: Setting restart_tolerance for the bg_jobs Supervisor**\nYou can configure the restart_tolerance setting for the supervisor, \nwhich determines how many restarts are tolerated in a given time \nwindow before the supervisor itself is terminated.\n```gleam\nstatic_supervisor.new(static_supervisor.OneForOne)   // Create a new supervisor with the OneForOne strategy\n|&gt; static_supervisor.restart_tolerance(10, 1)  // Set restart tolerance to 10 restarts in 1 second\n|&gt; bg_jobs.new(db_adapter)  // Create a new bg_jobs instance with the specified db_adapter\n|&gt; bg_jobs.build()  // Build and start the bg_jobs supervision tree\n```\nIn this example:\n- `sup.new(sup.OneForOne)` creates a new supervisor with the OneForOne strategy.\n- `sup.restart_tolerance(100, 1)` configures the supervisor to tolerate 100 restarts within a 1-second window.\n- `bg_jobs.new(db_adapter)` creates a new instance of bg_jobs, passing in the necessary db_adapter.\n- `bg_jobs.build()` builds and starts the bg_jobs system under the supervision tree.\n\n**Example 2: Supervising the bg_jobs Supervisor**\nYou can also add the bg_jobs supervisor as a child to another \nsupervisor, allowing you to control its lifecycle and supervise it \nas part of your system.\n```gleam\nfn setup_bg_jobs() -&gt; Result(bg_jobs.BgJobs, errors.BgJobError) {\n  // Define how the bg_jobs supervisor is set up\n  todo\n}\n\nstatic_supervisor.new(sup.OneForOne)   // Create a new supervisor with the OneForOne strategy\n|&gt; static_supervisor.add(static_supervisor.supervisor_child(&quot;bg_jobs&quot;, fn() {  // Add the bg_jobs supervisor as a child\n  setup_bg_jobs()  // Set up bg_jobs\n    |&gt; result.map(fn(bg) { bg.supervisor })  // Map the result to return the supervisors pid\n}))\n```\nIn this example:\n- `sup.new(sup.OneForOne)` creates a new supervisor with the OneForOne strategy.\n- `sup.add(sup.supervisor_child(&quot;bg_jobs&quot;, fn() { ... }))` adds the bg_jobs supervisor as a child of the main supervisor.\n- `setup_bg_jobs()` contains the logic for setting up the bg_jobs system, which could include creating job schedulers and configuring database adapters.\n- `result.map(fn(bg) { bg.supervisor })` ensures that the supervisor for the bg_jobs system is returned and supervised correctly.\n\n---\n# Monitor Process in bg_jobs\n\nThe Monitor process in bg_jobs is responsible for overseeing the \nhealth of all queues and scheduled job actors. It ensures that if \nany job or queue process dies unexpectedly, the corresponding \nreservation in the database is released, allowing other processes to \nreserve and process the job.\n## How it works\n\n### Monitoring Process Lifecycle\n- The monitor process uses `process.monitor_process()` from `gleam/erlang/\n  process` to track all queues and scheduled job \n  actors.\n- If a queue or scheduled job process dies, the monitor receives a \n  process down signal.\n- Upon receiving this signal, the monitor will release all \n  reservations made by that queue or job in the database. This makes \n  the job available for re-claiming.\n\n### Periodic Job Reservation Cleanup (Not implemented yet)\n- In cases where the monitor doesn&#39;t receive a process down signal \n  (e.g., if the signal is missed or delayed), it periodically loops \n  through reserved jobs in the database. \n- The monitor looks for jobs associated with dead processes, and \n  releases their reservation, allowing these jobs to be claimed again \n  by a new process. \n- The cleanup frequency is configurable, meaning you can define how \n  often the monitor checks for reserved jobs with dead processes. This \n  can be done using the configurable function some_fn().\n\n\n### Handling Monitor Failures\n- If the monitor itself dies, it’s designed to be fault-tolerant. \n  All queue and scheduled job processes are stored in an ETS (Erlang \n  Term Storage) table.\n- Upon restart, the monitor performs a cleanup operation, where it \n  releases reservations for jobs that were associated with dead \n  processes.\n- After cleanup, the monitor resumes its normal function by \n  restarting monitoring of the remaining alive processes.\n\n---\n\n# Queue\nEach queue that you add to the bg_jobs program spawns an `erlang/otp/\nactor` that manages that queue. It&#39;s responsible for polling the \ndatabase for jobs it has workers for. \n\n&gt;*A worker is added to a queue using the `queue.with_worker(Queue, Worker)` \n&gt;method.\n&gt;Jobs are added to the database by calling `bg_jobs.enqueue(JobRequest)` \n\nWhen a queue actor finds a job it can handle it claims that job by \nsetting the `reserved_at` and the `reserved_by` columns in the \ndatabase to the current datetime (UTC+0) and current processes \npid. This ensures no other queue claims that job \n\nIt then spawns a new process and executed the jobs worker with \nthe job data from the database in the new process.\n\nThe worker should not panic but instead return a result, if the \nworker panics the queue actor will crash and the supervisor will try \nto restart it.\nIf the job execution results in an ok a message is sent back to the \nqueue actor and the actor moves the job from the jobs table to \nthe jobs_succeeded table. \n\nHowever if the job execution results in an error, it&#39;s retried as \nmany times as specified by `queue.with_max_retries` (default: 3).\nShould the job not succeed within the max_retries a message is sent \nback to the queue actor and the actor moves the job from the jobs \ntable to the jobs_failed table with the string provided in the \nerror as the exception.\n\nMultiple queues may have the same workers meaning multiple queues \nmay be able to process the same type of jobs. This can be used to \nprioritize job execution. \n\nFor example if one type of job is extra important you could say all \nqueues can process that job type by specifying that jobs worker on \nall queues. Or maybe you have a default queue that can handle all \njobs and then add another queue for a specific job.\n\nJobs can have delayed processing either at a specific time or \nrelative time in the future. This can be specified with the\n`bg_jobs.job_with_available_at` or `job_with_available_in` \nrespectively.\n\n# Scheduled job\nScheduled jobs work the same way as queues internally with some key \ndifferences.\n\nEach scheduled job has 1 and only 1 worker meaning it can only \nhandle one type of job.\n\nA scheduled job is not manually enqueued. Instead on startup and successfull \nprocessing of a job the next processing time is calculated and the job is \nenqueued with the available_at value set to that next processing time.\n\nThis also means that if the job execution overlaps with what would \nbe the next processing time the job wont run that time.\n\nFor example if a job starts 13:30 and should run every minute the \nnext run time would be 13:31. But if the job execution takes 1min \n30sec. the next run will be at 13:32 since it&#39;s only rescheduled \nafter it completes.\n\n# Schedules\nSchedules for scheduled jobs can be specified in two ways. \nAs an interval or as a cron-like schedule\n\nScheduled jobs are either executing or waiting to be executed. Since \nthe job&#39;s next run is calculated on startup the first thing it does \nis wait.\nHowever if there already is a scheduled job when the actor starts it \nwill do nothing and wait for that job to become available.\n\n## Intervals \nIntervals is the simplest for of schedules provided. Intervals can \nbe specified in millieseconds, seconds, minutes, hours , days or \nweeks. This is done using the corresponding \n`scheduled_job.new_interval_[ time unit]()` functions, ex. \n`scheduled_job.new_interval_minutes(20)` would create a new interval \nof 20 minutes.\nExecution time is not included in the interval. This means, what you&#39;re \nreally setting, is how far in the future the job should be scheduled \nfor. \n\nTODO: diagram\n\n## Schedules\nSometimes you need to have more advanced schedules. For example you \nmay want a job run on the first day of the month at 08:30, or\non thursdays between the months march and june.\n\nThis can be achieved using schedules. Schedules allows you to \nspecify cron-like schedules ranges or specific values.\n\nTo achieve this flexibility, schedules are defined by configuring the \nfollowing time components:\n- Seconds: (Default: 0)\n- Minutes: (Default: Every)\n- Hours: (Default: Every)\n- Day of the Month: (Default: Every)\n- Month: (Default: Every)\n- Day of the Week: (Default: Every)\n\nEach component can be set to:\n*Every:* Matches all possible values for that component.\n*List:* A combination of:\n - Specific values (e.g., seconds 0, 15, 30).\n - Ranges (e.g., hours from 1 to 10).\nUsing List, you can mix specific values and ranges, allowing highly customized schedules.\n\n### Behavior of Every\nSetting a component to Every means it matches all possible values for that component. For example:\n&gt;Setting hours to Every will trigger the job at any hour, as long as other time units match their criteria.\n---\n### Schedule Validation\n\nSchedules are validated when the bg_jobs framework is started. If a \nschedule is invalid, a `ScheduleValidationError` is raised, preventing \nthe application from starting with an incorrect schedule configuration.\n\n**Common Validation Errors**\nAn invalid schedule can occur if:\n- A specified value is out of bounds for the time unit.\n  - Example: Scheduling a job for the 13th month, which does not exist.\n- A range is incorrectly defined (e.g., start is greater than end).\n  - Example: A between_seconds(50, 30) call would trigger an error.\n\n*Handling Validation Errors*\nIf the schedule is invalid a ScheduleValidationError is returned and \nwill stop the creation of bg_jobs, returning said error. The error \nmessage will provide details about the issue.\n\n---\n### ScheduleBuilder Functions\nThe ScheduleBuilder provides a series of methods to configure each time component.\n*Creating a New Schedule*\n```gleam\npub fn new_schedule() -&gt; ScheduleBuilder\n```\nCreates a new schedule with the default configuration: triggers at the first second of every minute.\n\n---\n### Configuring Seconds\n*every_second*\n```gleam\npub fn every_second(self: ScheduleBuilder) -&gt; ScheduleBuilder\n```\nSets the schedule to trigger at every second.\n\n*on_second*\n```gleam\npub fn on_second(self: ScheduleBuilder, second: Int) -&gt; ScheduleBuilder\n```\nAdds a specific second to the schedule. If other seconds are already \ndefined, this appends the new value.\n\n*Example:*\n```gleam\nschedule.on_second(1).on_second(10);\n// Triggers at second 1 or 10.\n```\n\n*between_seconds*\n```gleam\npub fn between_seconds(self: ScheduleBuilder, start: Int, end: Int) -&gt; ScheduleBuilder\n```\nAdds a range of seconds during which the schedule should trigger. If other seconds or ranges are already defined, this appends the range.\n\n\nExample:\n```gleam\nschedule.on_second(1).between_seconds(10, 15);\n// Triggers at second 1 or seconds 10–15.\n```\n\n---\n\n### Combining Filters\nFilters across time units are combined using AND logic. For example:\n```gleam\nlet schedule = new_schedule()\n    .on_second(1)\n    .between_seconds(10, 15)\n    .on_minute(30)\n    .on_hour(8)\n    .between_hours(14, 16)\n    .on_thursdays()\n    .between_months(3, 6);\n```\nThis schedule will trigger only when:\n- The second is 1 **or** within the range 10–15, **and**\n- The minute is 30, **and**\n- The hour is 8 **or** between 14:00–16:00, **and**\n- It is Thursday, **and**\n- It is during March through June.\n\n--- \n### Practical Example\nHere’s a complete example demonstrating both OR and AND logic:\n\n```gleam\nlet schedule = new_schedule()\n    .on_second(1)\n    .on_second(10)\n    .between_seconds(30, 40)\n    .on_minute(15)\n    .on_minute(45)\n    .on_hour(3)\n    .between_hours(10, 12)\n    .on_mondays() \n    .on_januaries()\n    .on_decembers();\n```\nThis schedule will trigger only when:\n- The second is 1, 10, **or** between 30–40, **and**\n- The minute is 15 **or** 45, **and**\n- The hour is 3 **or** between 10–12, **and**\n- It is Monday, **and**\n- It is January **or** December.\n\n---\n### Summary\n\nThe ScheduleBuilder provides a powerful and flexible way to define schedules:\n- **OR logic within each time unit** allows combining multiple specific values and ranges.\n- **AND logic across time units** ensures precise scheduling, requiring all units to match their criteria simultaneously. This design makes it easy to express even the most complex scheduling requirements.\n\n---\n## Event Listeners\nbg_jobs generates events during job processing, which can be used for \nlogging, monitoring, or custom telemetry. An event listener can be \nadded globally to capture all job events, or it can be attached to \nspecific queues or scheduled jobs for targeted monitoring.\n\nTo use the built-in logger_event_listener:\n```gleam\nbg_jobs.with_event_listener(logger_event_listener.listener)  // Logs events for all job processing events\n```\n\nCreating a Custom Event Listener\n\nImplement a custom event listener by defining a function with the \nfollowing signature:\n```gleam\npub type EventListener = fn(Event) -&gt; Nil\n```\n\nIf it&#39;s registered, this function will be called whenever an event \noccurs, receiving an Event object as its parameter. You can  \nregister your custom listener with bg_jobs (global listener), a queue,\nor a scheduled job as needed.\n\nExample of adding a custom event listener to a specific queue:\n```gleam\nqueue.with_event_listener(my_custom_event_listener())\n```\n\n## Db adapters\nbg_jobs includes two built-in database adapters: Postgres (via pog) and \nSQLite (via sqlight). These adapters allow seamless integration with \npopular databases, enabling you to use background job processing \nwithout additional dependencies. If you are using a different database, \nrefer to these implementations for guidance on building a compatible \nadapter.\n\nAdding a database adapter to bg_jobs:\n```gleam\nlet bg = bg_jobs.new(sqlite_db_adapter.new(conn, []))\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/bg_jobs&gt;.\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\njust watch-test # Run tests in watch mode\n```\n","url":"index.html"},{"doc":"bg_jobs/jobs","title":"FailedJob","content":"pub type FailedJob {\n  FailedJob(\n    id: String,\n    name: String,\n    payload: String,\n    attempts: Int,\n    exception: String,\n    created_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n    available_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n    failed_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n  )\n}\n Represents data about a failed job.\n\nFailedJob(\n  id: String,\n  name: String,\n  payload: String,\n  attempts: Int,\n  exception: String,\n  created_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n  available_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n  failed_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n)\n\n\nSynonyms:\nbg_jobs/jobs.FailedJob\nbg_jobs/jobs FailedJob","url":"bg_jobs/jobs.html#FailedJob"},{"doc":"bg_jobs/jobs","title":"Job","content":"pub type Job {\n  Job(\n    id: String,\n    name: String,\n    payload: String,\n    attempts: Int,\n    created_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n    available_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n    reserved_at: option.Option(\n      #(#(Int, Int, Int), #(Int, Int, Int)),\n    ),\n    reserved_by: option.Option(String),\n  )\n}\n It&#39;s the data representing a job in the queue.\n\n It contains all the necessary information to process the job.\n\nJob(\n  id: String,\n  name: String,\n  payload: String,\n  attempts: Int,\n  created_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n  available_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n  reserved_at: option.Option(\n    #(#(Int, Int, Int), #(Int, Int, Int)),\n  ),\n  reserved_by: option.Option(String),\n)\n\n\nSynonyms:\nbg_jobs/jobs.Job\nbg_jobs/jobs Job","url":"bg_jobs/jobs.html#Job"},{"doc":"bg_jobs/jobs","title":"JobAvailability","content":"pub type JobAvailability {\n  AvailableNow\n  AvailableAt(#(#(Int, Int, Int), #(Int, Int, Int)))\n  AvailableIn(Int)\n}\n Enum representing 3 ways of setting a jobs available_at \n\nAvailableNow\n\n\nAvailableAt(#(#(Int, Int, Int), #(Int, Int, Int)))\n\n\nAvailableIn(Int)\n\n\nSynonyms:\nbg_jobs/jobs.JobAvailability\nbg_jobs/jobs JobAvailability","url":"bg_jobs/jobs.html#JobAvailability"},{"doc":"bg_jobs/jobs","title":"JobEnqueueRequest","content":"pub type JobEnqueueRequest {\n  JobEnqueueRequest(\n    name: String,\n    payload: String,\n    availability: JobAvailability,\n  )\n}\n Data that is needed to enqueue a new job\n\nJobEnqueueRequest(\n  name: String,\n  payload: String,\n  availability: JobAvailability,\n)\n\n\nSynonyms:\nbg_jobs/jobs.JobEnqueueRequest\nbg_jobs/jobs JobEnqueueRequest","url":"bg_jobs/jobs.html#JobEnqueueRequest"},{"doc":"bg_jobs/jobs","title":"SucceededJob","content":"pub type SucceededJob {\n  SucceededJob(\n    id: String,\n    name: String,\n    payload: String,\n    attempts: Int,\n    created_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n    available_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n    succeeded_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n  )\n}\n Represents data about a succeeded job.\n\nSucceededJob(\n  id: String,\n  name: String,\n  payload: String,\n  attempts: Int,\n  created_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n  available_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n  succeeded_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n)\n\n\nSynonyms:\nbg_jobs/jobs.SucceededJob\nbg_jobs/jobs SucceededJob","url":"bg_jobs/jobs.html#SucceededJob"},{"doc":"bg_jobs/jobs","title":"Worker","content":"pub type Worker {\n  Worker(\n    job_name: String,\n    handler: fn(Job) -&gt; Result(Nil, String),\n  )\n}\n Represents a job-worker responsible for executing specific job.\n\n This is then what&#39;s registered to a queue or scheduled job.\n Each job must implement this type, defining the job name and \n its execution logic.\n \n\n ## Example\n\n \n pub fn worker(email_service: SomeService) {\n   Worker(job_name: &quot;send_email&quot;, execute: fn(job) { \n     from_string(job) \n     |&gt; email_service.send\n   })\n }\n \nWorker(job_name: String, handler: fn(Job) -&gt; Result(Nil, String))\n\n\nSynonyms:\nbg_jobs/jobs.Worker\nbg_jobs/jobs Worker","url":"bg_jobs/jobs.html#Worker"},{"doc":"bg_jobs/jobs","title":"new","content":"pub fn new(name: String, payload: String) -&gt; JobEnqueueRequest\n Create a new job_request\n\nSynonyms:\nbg_jobs/jobs.new\nbg_jobs/jobs new","url":"bg_jobs/jobs.html#new"},{"doc":"bg_jobs/jobs","title":"with_available_at","content":"pub fn with_available_at(\n  job_request: JobEnqueueRequest,\n  availabile_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n) -&gt; JobEnqueueRequest\n Set the availability of the job_request to a specific date-time\n\nSynonyms:\nbg_jobs/jobs.with_available_at\nbg_jobs/jobs with_available_at","url":"bg_jobs/jobs.html#with_available_at"},{"doc":"bg_jobs/jobs","title":"with_available_in","content":"pub fn with_available_in(\n  job_request: JobEnqueueRequest,\n  availabile_in: Int,\n) -&gt; JobEnqueueRequest\n Set the availability of the job_request to a time in the future\n\nSynonyms:\nbg_jobs/jobs.with_available_in\nbg_jobs/jobs with_available_in","url":"bg_jobs/jobs.html#with_available_in"},{"doc":"bg_jobs/jobs","title":"bg_jobs/jobs","content":"","url":"bg_jobs/jobs.html"},{"doc":"bg_jobs/errors","title":"BgJobError","content":"pub type BgJobError {\n  DbError(String)\n  ParseDateError(String)\n  DispatchJobError(String)\n  SetupError(dynamic.Dynamic)\n  ScheduleError(String)\n  ScheduleValidationError(String)\n  UnknownError(String)\n  NoWorkerForJobError(jobs.JobEnqueueRequest, List(jobs.Worker))\n  DateOutOfBoundsError(tempo.DateOutOfBoundsError)\n  TimeOutOfBoundsError(tempo.TimeOutOfBoundsError)\n}\n Represents errors that can occur during background job processing.\nDbError(String)\n\n\nParseDateError(String)\n\n\nDispatchJobError(String)\n\n\nSetupError(dynamic.Dynamic)\n\n\nScheduleError(String)\n\n\nScheduleValidationError(String)\n\n\nUnknownError(String)\n\n\nNoWorkerForJobError(jobs.JobEnqueueRequest, List(jobs.Worker))\n\n\nDateOutOfBoundsError(tempo.DateOutOfBoundsError)\n\n\nTimeOutOfBoundsError(tempo.TimeOutOfBoundsError)\n\n\nSynonyms:\nbg_jobs/errors.BgJobError\nbg_jobs/errors BgJobError","url":"bg_jobs/errors.html#BgJobError"},{"doc":"bg_jobs/errors","title":"bg_jobs/errors","content":"","url":"bg_jobs/errors.html"},{"doc":"bg_jobs/events","title":"Event","content":"pub type Event {\n  SetupErrorEvent(error: dynamic.Dynamic)\n  JobEnqueuedEvent(job: jobs.Job)\n  NoWorkerForJobError(job: jobs.JobEnqueueRequest)\n  JobReservedEvent(queue_name: String, job: jobs.Job)\n  JobStartEvent(queue_name: String, job: jobs.Job)\n  JobSucceededEvent(queue_name: String, job: jobs.Job)\n  JobFailedEvent(queue_name: String, job: jobs.Job)\n  QueuePollingStartedEvent(queue_name: String)\n  QueuePollingStopedEvent(queue_name: String)\n  QueueErrorEvent(queue_name: String, error: errors.BgJobError)\n  DbQueryEvent(sql: String, attributes: List(String))\n  DbEvent(operation: String, input: List(String))\n  DbResponseEvent(response: String)\n  DbErrorEvent(error: errors.BgJobError)\n  MonitorReleasingReserved(pid: process.Pid)\n  MonitorReleasedJob(jobs.Job)\n  MigrateUpComplete\n  MigrateDownComplete\n}\n\nSetupErrorEvent(error: dynamic.Dynamic)\n\n\nJobEnqueuedEvent(job: jobs.Job)\n\n\nNoWorkerForJobError(job: jobs.JobEnqueueRequest)\n\n\nJobReservedEvent(queue_name: String, job: jobs.Job)\n\n\nJobStartEvent(queue_name: String, job: jobs.Job)\n\n\nJobSucceededEvent(queue_name: String, job: jobs.Job)\n\n\nJobFailedEvent(queue_name: String, job: jobs.Job)\n\n\nQueuePollingStartedEvent(queue_name: String)\n\n\nQueuePollingStopedEvent(queue_name: String)\n\n\nQueueErrorEvent(queue_name: String, error: errors.BgJobError)\n\n\nDbQueryEvent(sql: String, attributes: List(String))\n\n\nDbEvent(operation: String, input: List(String))\n\n\nDbResponseEvent(response: String)\n\n\nDbErrorEvent(error: errors.BgJobError)\n\n\nMonitorReleasingReserved(pid: process.Pid)\n\n\nMonitorReleasedJob(jobs.Job)\n\n\nMigrateUpComplete\n\n\nMigrateDownComplete\n\n\nSynonyms:\nbg_jobs/events.Event\nbg_jobs/events Event","url":"bg_jobs/events.html#Event"},{"doc":"bg_jobs/events","title":"EventListener","content":"pub type EventListener =\n  fn(Event) -&gt; Nil\n\n\nSynonyms:\nbg_jobs/events.EventListener\nbg_jobs/events EventListener","url":"bg_jobs/events.html#EventListener"},{"doc":"bg_jobs/events","title":"send_event","content":"pub fn send_event(\n  event_listners: List(fn(Event) -&gt; Nil),\n  event: Event,\n) -&gt; Nil\n\nSynonyms:\nbg_jobs/events.send_event\nbg_jobs/events send_event","url":"bg_jobs/events.html#send_event"},{"doc":"bg_jobs/events","title":"bg_jobs/events","content":"","url":"bg_jobs/events.html"},{"doc":"bg_jobs/db_adapter","title":"DbAdapter","content":"pub type DbAdapter {\n  DbAdapter(\n    enqueue_job: fn(\n      String,\n      String,\n      #(#(Int, Int, Int), #(Int, Int, Int)),\n    ) -&gt;\n      Result(jobs.Job, errors.BgJobError),\n    reserve_jobs: fn(List(String), Int, String) -&gt;\n      Result(List(jobs.Job), errors.BgJobError),\n    release_reservation: fn(String) -&gt;\n      Result(jobs.Job, errors.BgJobError),\n    release_jobs_reserved_by: fn(String) -&gt;\n      Result(List(jobs.Job), errors.BgJobError),\n    move_job_to_succeeded: fn(jobs.Job) -&gt;\n      Result(Nil, errors.BgJobError),\n    move_job_to_failed: fn(jobs.Job, String) -&gt;\n      Result(Nil, errors.BgJobError),\n    increment_attempts: fn(jobs.Job) -&gt;\n      Result(jobs.Job, errors.BgJobError),\n    get_enqueued_jobs: fn(String) -&gt;\n      Result(List(jobs.Job), errors.BgJobError),\n    get_running_jobs: fn() -&gt;\n      Result(List(jobs.Job), errors.BgJobError),\n    get_running_jobs_by_queue_name: fn(String) -&gt;\n      Result(List(jobs.Job), errors.BgJobError),\n    get_succeeded_jobs: fn(Int) -&gt;\n      Result(List(jobs.SucceededJob), errors.BgJobError),\n    get_failed_jobs: fn(Int) -&gt;\n      Result(List(jobs.FailedJob), errors.BgJobError),\n    migrate_up: fn(List(events.EventListener)) -&gt;\n      Result(Nil, errors.BgJobError),\n    migrate_down: fn(List(events.EventListener)) -&gt;\n      Result(Nil, errors.BgJobError),\n  )\n}\n Defines the interface for database interactions related to job management.\n\n Each database implementation must provide functions to enqueue, retrieve, and manage jobs.\n\nDbAdapter(\n  enqueue_job: fn(\n    String,\n    String,\n    #(#(Int, Int, Int), #(Int, Int, Int)),\n  ) -&gt;\n    Result(jobs.Job, errors.BgJobError),\n  reserve_jobs: fn(List(String), Int, String) -&gt;\n    Result(List(jobs.Job), errors.BgJobError),\n  release_reservation: fn(String) -&gt;\n    Result(jobs.Job, errors.BgJobError),\n  release_jobs_reserved_by: fn(String) -&gt;\n    Result(List(jobs.Job), errors.BgJobError),\n  move_job_to_succeeded: fn(jobs.Job) -&gt;\n    Result(Nil, errors.BgJobError),\n  move_job_to_failed: fn(jobs.Job, String) -&gt;\n    Result(Nil, errors.BgJobError),\n  increment_attempts: fn(jobs.Job) -&gt;\n    Result(jobs.Job, errors.BgJobError),\n  get_enqueued_jobs: fn(String) -&gt;\n    Result(List(jobs.Job), errors.BgJobError),\n  get_running_jobs: fn() -&gt;\n    Result(List(jobs.Job), errors.BgJobError),\n  get_running_jobs_by_queue_name: fn(String) -&gt;\n    Result(List(jobs.Job), errors.BgJobError),\n  get_succeeded_jobs: fn(Int) -&gt;\n    Result(List(jobs.SucceededJob), errors.BgJobError),\n  get_failed_jobs: fn(Int) -&gt;\n    Result(List(jobs.FailedJob), errors.BgJobError),\n  migrate_up: fn(List(events.EventListener)) -&gt;\n    Result(Nil, errors.BgJobError),\n  migrate_down: fn(List(events.EventListener)) -&gt;\n    Result(Nil, errors.BgJobError),\n)\n\n\nSynonyms:\nbg_jobs/db_adapter.DbAdapter\nbg_jobs/db_adapter DbAdapter","url":"bg_jobs/db_adapter.html#DbAdapter"},{"doc":"bg_jobs/db_adapter","title":"bg_jobs/db_adapter","content":"","url":"bg_jobs/db_adapter.html"},{"doc":"bg_jobs/queue","title":"Message","content":"pub type Message {\n  Shutdown\n  StartPolling\n  StopPolling\n  WaitBetweenPoll\n  HandleError(jobs.Job, exception: String)\n  HandleSuccess(jobs.Job)\n  ProcessJobs\n}\n\nShutdown\n\n\nStartPolling\n\n\nStopPolling\n\n\nWaitBetweenPoll\n\n\nHandleError(jobs.Job, exception: String)\n\n\nHandleSuccess(jobs.Job)\n\n\nProcessJobs\n\n\nSynonyms:\nbg_jobs/queue.Message\nbg_jobs/queue Message","url":"bg_jobs/queue.html#Message"},{"doc":"bg_jobs/queue","title":"Spec","content":"pub type Spec {\n  Spec(\n    name: String,\n    workers: List(jobs.Worker),\n    max_retries: Int,\n    init_timeout: Int,\n    max_concurrent_jobs: Int,\n    poll_interval: Int,\n    event_listeners: List(events.EventListener),\n  )\n}\n Represents a queue that should be created\n\nSpec(\n  name: String,\n  workers: List(jobs.Worker),\n  max_retries: Int,\n  init_timeout: Int,\n  max_concurrent_jobs: Int,\n  poll_interval: Int,\n  event_listeners: List(events.EventListener),\n)\n\n\nSynonyms:\nbg_jobs/queue.Spec\nbg_jobs/queue Spec","url":"bg_jobs/queue.html#Spec"},{"doc":"bg_jobs/queue","title":"new","content":"pub fn new(name: String) -&gt; Spec\n Start building a new queue-spec \n\n NOTE: Name needs to be the same on restarts, but unique across all\n queues, even if running on different machines\n\nSynonyms:\nbg_jobs/queue.new\nbg_jobs/queue new","url":"bg_jobs/queue.html#new"},{"doc":"bg_jobs/queue","title":"with_event_listener","content":"pub fn with_event_listener(\n  spec: Spec,\n  event_listener: fn(Event) -&gt; Nil,\n) -&gt; Spec\n Add a event listener to the list of event listners for the queue\n\nSynonyms:\nbg_jobs/queue.with_event_listener\nbg_jobs/queue with_event_listener","url":"bg_jobs/queue.html#with_event_listener"},{"doc":"bg_jobs/queue","title":"with_event_listeners","content":"pub fn with_event_listeners(\n  spec: Spec,\n  event_listeners: List(fn(Event) -&gt; Nil),\n) -&gt; Spec\n Append a list of event listeners for the queue\n\nSynonyms:\nbg_jobs/queue.with_event_listeners\nbg_jobs/queue with_event_listeners","url":"bg_jobs/queue.html#with_event_listeners"},{"doc":"bg_jobs/queue","title":"with_init_timeout","content":"pub fn with_init_timeout(spec: Spec, init_timeout: Int) -&gt; Spec\n Amount of time in milliseconds the queue is given to start\n\nSynonyms:\nbg_jobs/queue.with_init_timeout\nbg_jobs/queue with_init_timeout","url":"bg_jobs/queue.html#with_init_timeout"},{"doc":"bg_jobs/queue","title":"with_max_concurrent_jobs","content":"pub fn with_max_concurrent_jobs(\n  spec: Spec,\n  max_concurrent_jobs: Int,\n) -&gt; Spec\n Maximum number of jobs to run in parallel\n\nSynonyms:\nbg_jobs/queue.with_max_concurrent_jobs\nbg_jobs/queue with_max_concurrent_jobs","url":"bg_jobs/queue.html#with_max_concurrent_jobs"},{"doc":"bg_jobs/queue","title":"with_max_retries","content":"pub fn with_max_retries(spec: Spec, max_retries: Int) -&gt; Spec\n Maximum times a job will be retried before being considered failed\n and moved to the failed_jobs table\n\nSynonyms:\nbg_jobs/queue.with_max_retries\nbg_jobs/queue with_max_retries","url":"bg_jobs/queue.html#with_max_retries"},{"doc":"bg_jobs/queue","title":"with_name","content":"pub fn with_name(spec: Spec, name: String) -&gt; Spec\n Set the name of the queue\n\n NOTE: This needs to be the same on restarts, but unique across all\n queues, even if running on different machines\n\nSynonyms:\nbg_jobs/queue.with_name\nbg_jobs/queue with_name","url":"bg_jobs/queue.html#with_name"},{"doc":"bg_jobs/queue","title":"with_poll_interval_ms","content":"pub fn with_poll_interval_ms(\n  spec: Spec,\n  poll_interval: Int,\n) -&gt; Spec\n Time in milli seconds to wait in between checking for new jobs\n\nSynonyms:\nbg_jobs/queue.with_poll_interval_ms\nbg_jobs/queue with_poll_interval_ms","url":"bg_jobs/queue.html#with_poll_interval_ms"},{"doc":"bg_jobs/queue","title":"with_worker","content":"pub fn with_worker(spec: Spec, worker: Worker) -&gt; Spec\n Add a worker the queue will poll for and run\n\nSynonyms:\nbg_jobs/queue.with_worker\nbg_jobs/queue with_worker","url":"bg_jobs/queue.html#with_worker"},{"doc":"bg_jobs/queue","title":"with_workers","content":"pub fn with_workers(spec: Spec, workers: List(Worker)) -&gt; Spec\n Add multiple workers the queue will poll for and run\n\nSynonyms:\nbg_jobs/queue.with_workers\nbg_jobs/queue with_workers","url":"bg_jobs/queue.html#with_workers"},{"doc":"bg_jobs/queue","title":"bg_jobs/queue","content":"","url":"bg_jobs/queue.html"},{"doc":"bg_jobs/scheduled_job","title":"DateError","content":"pub type DateError {\n  DateError(tempo.DateOutOfBoundsError)\n  TimeError(tempo.TimeOutOfBoundsError)\n  OutOfBoundsError(String)\n  RangeError(String)\n}\n\nDateError(tempo.DateOutOfBoundsError)\n\n\nTimeError(tempo.TimeOutOfBoundsError)\n\n\nOutOfBoundsError(String)\n\n\nRangeError(String)\n\n\nSynonyms:\nbg_jobs/scheduled_job.DateError\nbg_jobs/scheduled_job DateError","url":"bg_jobs/scheduled_job.html#DateError"},{"doc":"bg_jobs/scheduled_job","title":"DateSchedule","content":"pub type DateSchedule {\n  DateSchedule(\n    second: TimeValue,\n    minute: TimeValue,\n    hour: TimeValue,\n    day_of_month: TimeValue,\n    month: TimeValue,\n    day_of_week: TimeValue,\n  )\n}\n\nDateSchedule(\n  second: TimeValue,\n  minute: TimeValue,\n  hour: TimeValue,\n  day_of_month: TimeValue,\n  month: TimeValue,\n  day_of_week: TimeValue,\n)\n\n\nSynonyms:\nbg_jobs/scheduled_job.DateSchedule\nbg_jobs/scheduled_job DateSchedule","url":"bg_jobs/scheduled_job.html#DateSchedule"},{"doc":"bg_jobs/scheduled_job","title":"DateScheduleBuilder","content":"pub type DateScheduleBuilder {\n  DateScheduleBuilder(\n    second: TimeValue,\n    minute: TimeValue,\n    hour: TimeValue,\n    day_of_month: TimeValue,\n    month: TimeValue,\n    day_of_week: TimeValue,\n  )\n}\n\nDateScheduleBuilder(\n  second: TimeValue,\n  minute: TimeValue,\n  hour: TimeValue,\n  day_of_month: TimeValue,\n  month: TimeValue,\n  day_of_week: TimeValue,\n)\n\n\nSynonyms:\nbg_jobs/scheduled_job.DateScheduleBuilder\nbg_jobs/scheduled_job DateScheduleBuilder","url":"bg_jobs/scheduled_job.html#DateScheduleBuilder"},{"doc":"bg_jobs/scheduled_job","title":"Duration","content":"pub type Duration {\n  Millisecond(Int)\n  Second(Int)\n  Minute(Int)\n  Hour(Int)\n  Day(Int)\n  Week(Int)\n}\n\nMillisecond(Int)\n\n\nSecond(Int)\n\n\nMinute(Int)\n\n\nHour(Int)\n\n\nDay(Int)\n\n\nWeek(Int)\n\n\nSynonyms:\nbg_jobs/scheduled_job.Duration\nbg_jobs/scheduled_job Duration","url":"bg_jobs/scheduled_job.html#Duration"},{"doc":"bg_jobs/scheduled_job","title":"Schedule","content":"pub type Schedule {\n  Interval(Duration)\n  Schedule(DateSchedule)\n}\n\nInterval(Duration)\n\n\nSchedule(DateSchedule)\n\n\nSynonyms:\nbg_jobs/scheduled_job.Schedule\nbg_jobs/scheduled_job Schedule","url":"bg_jobs/scheduled_job.html#Schedule"},{"doc":"bg_jobs/scheduled_job","title":"ScheduleBuilder","content":"pub type ScheduleBuilder {\n  IntervalBuilder(Duration)\n  ScheduleBuilder(DateScheduleBuilder)\n}\n\nIntervalBuilder(Duration)\n\n\nScheduleBuilder(DateScheduleBuilder)\n\n\nSynonyms:\nbg_jobs/scheduled_job.ScheduleBuilder\nbg_jobs/scheduled_job ScheduleBuilder","url":"bg_jobs/scheduled_job.html#ScheduleBuilder"},{"doc":"bg_jobs/scheduled_job","title":"Spec","content":"pub type Spec {\n  Spec(\n    schedule: Schedule,\n    worker: jobs.Worker,\n    max_retries: Int,\n    init_timeout: Int,\n    poll_interval: Int,\n    event_listeners: List(events.EventListener),\n  )\n}\n\nSpec(\n  schedule: Schedule,\n  worker: jobs.Worker,\n  max_retries: Int,\n  init_timeout: Int,\n  poll_interval: Int,\n  event_listeners: List(events.EventListener),\n)\n\n\nSynonyms:\nbg_jobs/scheduled_job.Spec\nbg_jobs/scheduled_job Spec","url":"bg_jobs/scheduled_job.html#Spec"},{"doc":"bg_jobs/scheduled_job","title":"SpecBuilder","content":"pub type SpecBuilder {\n  SpecBuilder(\n    schedule_builder: ScheduleBuilder,\n    worker: jobs.Worker,\n    max_retries: Int,\n    init_timeout: Int,\n    poll_interval: Int,\n    event_listeners: List(events.EventListener),\n  )\n}\n\nSpecBuilder(\n  schedule_builder: ScheduleBuilder,\n  worker: jobs.Worker,\n  max_retries: Int,\n  init_timeout: Int,\n  poll_interval: Int,\n  event_listeners: List(events.EventListener),\n)\n\n\nSynonyms:\nbg_jobs/scheduled_job.SpecBuilder\nbg_jobs/scheduled_job SpecBuilder","url":"bg_jobs/scheduled_job.html#SpecBuilder"},{"doc":"bg_jobs/scheduled_job","title":"TimeSelection","content":"pub type TimeSelection {\n  Value(Int)\n  Range(Int, Int)\n}\n\nValue(Int)\n\n\nRange(Int, Int)\n\n\nSynonyms:\nbg_jobs/scheduled_job.TimeSelection\nbg_jobs/scheduled_job TimeSelection","url":"bg_jobs/scheduled_job.html#TimeSelection"},{"doc":"bg_jobs/scheduled_job","title":"TimeValue","content":"pub type TimeValue {\n  Every\n  Specific(List(TimeSelection))\n}\n\nEvery\n\n\nSpecific(List(TimeSelection))\n\n\nSynonyms:\nbg_jobs/scheduled_job.TimeValue\nbg_jobs/scheduled_job TimeValue","url":"bg_jobs/scheduled_job.html#TimeValue"},{"doc":"bg_jobs/scheduled_job","title":"between_day_of_months","content":"pub fn between_day_of_months(\n  self: ScheduleBuilder,\n  start: Int,\n  end: Int,\n) -&gt; ScheduleBuilder\n Sets a range of days of the month during which the schedule should trigger.\nSynonyms:\nbg_jobs/scheduled_job.between_day_of_months\nbg_jobs/scheduled_job between_day_of_months","url":"bg_jobs/scheduled_job.html#between_day_of_months"},{"doc":"bg_jobs/scheduled_job","title":"between_day_of_weeks","content":"pub fn between_day_of_weeks(\n  self: ScheduleBuilder,\n  start: Int,\n  end: Int,\n) -&gt; ScheduleBuilder\n Sets a range of days of the week during which the schedule should trigger.\nSynonyms:\nbg_jobs/scheduled_job.between_day_of_weeks\nbg_jobs/scheduled_job between_day_of_weeks","url":"bg_jobs/scheduled_job.html#between_day_of_weeks"},{"doc":"bg_jobs/scheduled_job","title":"between_hours","content":"pub fn between_hours(\n  self: ScheduleBuilder,\n  start: Int,\n  end: Int,\n) -&gt; ScheduleBuilder\n Sets a range of hours during which the schedule should trigger.\nSynonyms:\nbg_jobs/scheduled_job.between_hours\nbg_jobs/scheduled_job between_hours","url":"bg_jobs/scheduled_job.html#between_hours"},{"doc":"bg_jobs/scheduled_job","title":"between_minutes","content":"pub fn between_minutes(\n  self: ScheduleBuilder,\n  start: Int,\n  end: Int,\n) -&gt; ScheduleBuilder\n Sets a range of minutes during which the schedule should trigger.\nSynonyms:\nbg_jobs/scheduled_job.between_minutes\nbg_jobs/scheduled_job between_minutes","url":"bg_jobs/scheduled_job.html#between_minutes"},{"doc":"bg_jobs/scheduled_job","title":"between_months","content":"pub fn between_months(\n  self: ScheduleBuilder,\n  start: Int,\n  end: Int,\n) -&gt; ScheduleBuilder\n Sets a range of months during which the schedule should trigger.\nSynonyms:\nbg_jobs/scheduled_job.between_months\nbg_jobs/scheduled_job between_months","url":"bg_jobs/scheduled_job.html#between_months"},{"doc":"bg_jobs/scheduled_job","title":"between_seconds","content":"pub fn between_seconds(\n  self: ScheduleBuilder,\n  start: Int,\n  end: Int,\n) -&gt; ScheduleBuilder\n Sets a range of seconds during which the schedule should trigger.\nSynonyms:\nbg_jobs/scheduled_job.between_seconds\nbg_jobs/scheduled_job between_seconds","url":"bg_jobs/scheduled_job.html#between_seconds"},{"doc":"bg_jobs/scheduled_job","title":"build","content":"pub fn build(\n  db_adapter db_adapter: DbAdapter,\n  spec spec: Spec,\n) -&gt; Result(Subject(Message), StartError)\n\nSynonyms:\nbg_jobs/scheduled_job.build\nbg_jobs/scheduled_job build","url":"bg_jobs/scheduled_job.html#build"},{"doc":"bg_jobs/scheduled_job","title":"build_schedule","content":"pub fn build_schedule(\n  schedule_in: ScheduleBuilder,\n) -&gt; Result(Schedule, DateError)\n Validate and create Schedule from scheduleBuilder \nSynonyms:\nbg_jobs/scheduled_job.build_schedule\nbg_jobs/scheduled_job build_schedule","url":"bg_jobs/scheduled_job.html#build_schedule"},{"doc":"bg_jobs/scheduled_job","title":"every_second","content":"pub fn every_second(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Sets the schedule to trigger every second.\nSynonyms:\nbg_jobs/scheduled_job.every_second\nbg_jobs/scheduled_job every_second","url":"bg_jobs/scheduled_job.html#every_second"},{"doc":"bg_jobs/scheduled_job","title":"map_schedule_builder","content":"pub fn map_schedule_builder(\n  schedule: ScheduleBuilder,\n  f: fn(DateScheduleBuilder) -&gt; DateScheduleBuilder,\n) -&gt; ScheduleBuilder\n\nSynonyms:\nbg_jobs/scheduled_job.map_schedule_builder\nbg_jobs/scheduled_job map_schedule_builder","url":"bg_jobs/scheduled_job.html#map_schedule_builder"},{"doc":"bg_jobs/scheduled_job","title":"new","content":"pub fn new(\n  worker worker: Worker,\n  schedule schedule: ScheduleBuilder,\n) -&gt; SpecBuilder\n\nSynonyms:\nbg_jobs/scheduled_job.new\nbg_jobs/scheduled_job new","url":"bg_jobs/scheduled_job.html#new"},{"doc":"bg_jobs/scheduled_job","title":"new_interval_days","content":"pub fn new_interval_days(days: Int) -&gt; ScheduleBuilder\n Create interval schedule in days\nSynonyms:\nbg_jobs/scheduled_job.new_interval_days\nbg_jobs/scheduled_job new_interval_days","url":"bg_jobs/scheduled_job.html#new_interval_days"},{"doc":"bg_jobs/scheduled_job","title":"new_interval_hours","content":"pub fn new_interval_hours(hours: Int) -&gt; ScheduleBuilder\n Create interval schedule in hours\nSynonyms:\nbg_jobs/scheduled_job.new_interval_hours\nbg_jobs/scheduled_job new_interval_hours","url":"bg_jobs/scheduled_job.html#new_interval_hours"},{"doc":"bg_jobs/scheduled_job","title":"new_interval_milliseconds","content":"pub fn new_interval_milliseconds(\n  milliseconds: Int,\n) -&gt; ScheduleBuilder\n Create interval schedule in milliseconds\nSynonyms:\nbg_jobs/scheduled_job.new_interval_milliseconds\nbg_jobs/scheduled_job new_interval_milliseconds","url":"bg_jobs/scheduled_job.html#new_interval_milliseconds"},{"doc":"bg_jobs/scheduled_job","title":"new_interval_minutes","content":"pub fn new_interval_minutes(minutes: Int) -&gt; ScheduleBuilder\n Create interval schedule in minutes\nSynonyms:\nbg_jobs/scheduled_job.new_interval_minutes\nbg_jobs/scheduled_job new_interval_minutes","url":"bg_jobs/scheduled_job.html#new_interval_minutes"},{"doc":"bg_jobs/scheduled_job","title":"new_interval_seconds","content":"pub fn new_interval_seconds(seconds: Int) -&gt; ScheduleBuilder\n Create interval schedule in seconds\nSynonyms:\nbg_jobs/scheduled_job.new_interval_seconds\nbg_jobs/scheduled_job new_interval_seconds","url":"bg_jobs/scheduled_job.html#new_interval_seconds"},{"doc":"bg_jobs/scheduled_job","title":"new_interval_weeks","content":"pub fn new_interval_weeks(weeks: Int) -&gt; ScheduleBuilder\n Create interval schedule in weeks\nSynonyms:\nbg_jobs/scheduled_job.new_interval_weeks\nbg_jobs/scheduled_job new_interval_weeks","url":"bg_jobs/scheduled_job.html#new_interval_weeks"},{"doc":"bg_jobs/scheduled_job","title":"new_schedule","content":"pub fn new_schedule() -&gt; ScheduleBuilder\n Create a new schedule that runs on the first second\n every minut\nSynonyms:\nbg_jobs/scheduled_job.new_schedule\nbg_jobs/scheduled_job new_schedule","url":"bg_jobs/scheduled_job.html#new_schedule"},{"doc":"bg_jobs/scheduled_job","title":"on_aprils","content":"pub fn on_aprils(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger in April.\nSynonyms:\nbg_jobs/scheduled_job.on_aprils\nbg_jobs/scheduled_job on_aprils","url":"bg_jobs/scheduled_job.html#on_aprils"},{"doc":"bg_jobs/scheduled_job","title":"on_augusts","content":"pub fn on_augusts(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger in August.\nSynonyms:\nbg_jobs/scheduled_job.on_augusts\nbg_jobs/scheduled_job on_augusts","url":"bg_jobs/scheduled_job.html#on_augusts"},{"doc":"bg_jobs/scheduled_job","title":"on_day_of_month","content":"pub fn on_day_of_month(\n  self: ScheduleBuilder,\n  value: Int,\n) -&gt; ScheduleBuilder\n Adds a specific day of the month on which the schedule should trigger.\n If other specific days are already set, appends the given day.\nSynonyms:\nbg_jobs/scheduled_job.on_day_of_month\nbg_jobs/scheduled_job on_day_of_month","url":"bg_jobs/scheduled_job.html#on_day_of_month"},{"doc":"bg_jobs/scheduled_job","title":"on_day_of_week","content":"pub fn on_day_of_week(\n  self: ScheduleBuilder,\n  value: Int,\n) -&gt; ScheduleBuilder\n Adds a specific day of the week on which the schedule should trigger.\n If other specific days are already set, appends the given day.\nSynonyms:\nbg_jobs/scheduled_job.on_day_of_week\nbg_jobs/scheduled_job on_day_of_week","url":"bg_jobs/scheduled_job.html#on_day_of_week"},{"doc":"bg_jobs/scheduled_job","title":"on_decembers","content":"pub fn on_decembers(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger in December.\nSynonyms:\nbg_jobs/scheduled_job.on_decembers\nbg_jobs/scheduled_job on_decembers","url":"bg_jobs/scheduled_job.html#on_decembers"},{"doc":"bg_jobs/scheduled_job","title":"on_februaries","content":"pub fn on_februaries(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger in February.\nSynonyms:\nbg_jobs/scheduled_job.on_februaries\nbg_jobs/scheduled_job on_februaries","url":"bg_jobs/scheduled_job.html#on_februaries"},{"doc":"bg_jobs/scheduled_job","title":"on_fridays","content":"pub fn on_fridays(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger on Fridays.\nSynonyms:\nbg_jobs/scheduled_job.on_fridays\nbg_jobs/scheduled_job on_fridays","url":"bg_jobs/scheduled_job.html#on_fridays"},{"doc":"bg_jobs/scheduled_job","title":"on_hour","content":"pub fn on_hour(\n  self: ScheduleBuilder,\n  value: Int,\n) -&gt; ScheduleBuilder\n Adds a specific hour at which the schedule should trigger.\n If other specific hours are already set, appends the given hour.\nSynonyms:\nbg_jobs/scheduled_job.on_hour\nbg_jobs/scheduled_job on_hour","url":"bg_jobs/scheduled_job.html#on_hour"},{"doc":"bg_jobs/scheduled_job","title":"on_januaries","content":"pub fn on_januaries(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger in January.\nSynonyms:\nbg_jobs/scheduled_job.on_januaries\nbg_jobs/scheduled_job on_januaries","url":"bg_jobs/scheduled_job.html#on_januaries"},{"doc":"bg_jobs/scheduled_job","title":"on_julies","content":"pub fn on_julies(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger in July.\nSynonyms:\nbg_jobs/scheduled_job.on_julies\nbg_jobs/scheduled_job on_julies","url":"bg_jobs/scheduled_job.html#on_julies"},{"doc":"bg_jobs/scheduled_job","title":"on_junes","content":"pub fn on_junes(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger in June.\nSynonyms:\nbg_jobs/scheduled_job.on_junes\nbg_jobs/scheduled_job on_junes","url":"bg_jobs/scheduled_job.html#on_junes"},{"doc":"bg_jobs/scheduled_job","title":"on_marches","content":"pub fn on_marches(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger in March.\nSynonyms:\nbg_jobs/scheduled_job.on_marches\nbg_jobs/scheduled_job on_marches","url":"bg_jobs/scheduled_job.html#on_marches"},{"doc":"bg_jobs/scheduled_job","title":"on_mays","content":"pub fn on_mays(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger in May.\nSynonyms:\nbg_jobs/scheduled_job.on_mays\nbg_jobs/scheduled_job on_mays","url":"bg_jobs/scheduled_job.html#on_mays"},{"doc":"bg_jobs/scheduled_job","title":"on_minute","content":"pub fn on_minute(\n  self: ScheduleBuilder,\n  value: Int,\n) -&gt; ScheduleBuilder\n Adds a specific minute at which the schedule should trigger.\n If other specific minutes are already set, appends the given minute.\nSynonyms:\nbg_jobs/scheduled_job.on_minute\nbg_jobs/scheduled_job on_minute","url":"bg_jobs/scheduled_job.html#on_minute"},{"doc":"bg_jobs/scheduled_job","title":"on_mondays","content":"pub fn on_mondays(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger on Mondays.\nSynonyms:\nbg_jobs/scheduled_job.on_mondays\nbg_jobs/scheduled_job on_mondays","url":"bg_jobs/scheduled_job.html#on_mondays"},{"doc":"bg_jobs/scheduled_job","title":"on_month","content":"pub fn on_month(\n  self: ScheduleBuilder,\n  value: Int,\n) -&gt; ScheduleBuilder\n Adds a specific month in which the schedule should trigger.\n If other specific months are already set, appends the given month.\nSynonyms:\nbg_jobs/scheduled_job.on_month\nbg_jobs/scheduled_job on_month","url":"bg_jobs/scheduled_job.html#on_month"},{"doc":"bg_jobs/scheduled_job","title":"on_novembers","content":"pub fn on_novembers(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger in November.\nSynonyms:\nbg_jobs/scheduled_job.on_novembers\nbg_jobs/scheduled_job on_novembers","url":"bg_jobs/scheduled_job.html#on_novembers"},{"doc":"bg_jobs/scheduled_job","title":"on_octobers","content":"pub fn on_octobers(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger in October.\nSynonyms:\nbg_jobs/scheduled_job.on_octobers\nbg_jobs/scheduled_job on_octobers","url":"bg_jobs/scheduled_job.html#on_octobers"},{"doc":"bg_jobs/scheduled_job","title":"on_saturdays","content":"pub fn on_saturdays(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger on Saturdays.\nSynonyms:\nbg_jobs/scheduled_job.on_saturdays\nbg_jobs/scheduled_job on_saturdays","url":"bg_jobs/scheduled_job.html#on_saturdays"},{"doc":"bg_jobs/scheduled_job","title":"on_second","content":"pub fn on_second(\n  self: ScheduleBuilder,\n  second: Int,\n) -&gt; ScheduleBuilder\n Adds a specific second at which the schedule should trigger.\n If other specific seconds are already set, appends the given second.\n \n Note: the default value is to trigger on second 0 so you would \n need to set it to every second first and then to a specific to \n only get that \nSynonyms:\nbg_jobs/scheduled_job.on_second\nbg_jobs/scheduled_job on_second","url":"bg_jobs/scheduled_job.html#on_second"},{"doc":"bg_jobs/scheduled_job","title":"on_septembers","content":"pub fn on_septembers(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger in September.\nSynonyms:\nbg_jobs/scheduled_job.on_septembers\nbg_jobs/scheduled_job on_septembers","url":"bg_jobs/scheduled_job.html#on_septembers"},{"doc":"bg_jobs/scheduled_job","title":"on_sundays","content":"pub fn on_sundays(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger on Sundays.\nSynonyms:\nbg_jobs/scheduled_job.on_sundays\nbg_jobs/scheduled_job on_sundays","url":"bg_jobs/scheduled_job.html#on_sundays"},{"doc":"bg_jobs/scheduled_job","title":"on_thuesdays","content":"pub fn on_thuesdays(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger on Thuesdays.\nSynonyms:\nbg_jobs/scheduled_job.on_thuesdays\nbg_jobs/scheduled_job on_thuesdays","url":"bg_jobs/scheduled_job.html#on_thuesdays"},{"doc":"bg_jobs/scheduled_job","title":"on_thursdays","content":"pub fn on_thursdays(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger on Thursdays.\nSynonyms:\nbg_jobs/scheduled_job.on_thursdays\nbg_jobs/scheduled_job on_thursdays","url":"bg_jobs/scheduled_job.html#on_thursdays"},{"doc":"bg_jobs/scheduled_job","title":"on_wednesdays","content":"pub fn on_wednesdays(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger on Wednesdays.\nSynonyms:\nbg_jobs/scheduled_job.on_wednesdays\nbg_jobs/scheduled_job on_wednesdays","url":"bg_jobs/scheduled_job.html#on_wednesdays"},{"doc":"bg_jobs/scheduled_job","title":"on_weekdays","content":"pub fn on_weekdays(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger on weekdays (Monday through Friday).\nSynonyms:\nbg_jobs/scheduled_job.on_weekdays\nbg_jobs/scheduled_job on_weekdays","url":"bg_jobs/scheduled_job.html#on_weekdays"},{"doc":"bg_jobs/scheduled_job","title":"on_weekends","content":"pub fn on_weekends(self: ScheduleBuilder) -&gt; ScheduleBuilder\n Shortcut function to set the schedule to trigger on weekends (Saturday and Sunday).\nSynonyms:\nbg_jobs/scheduled_job.on_weekends\nbg_jobs/scheduled_job on_weekends","url":"bg_jobs/scheduled_job.html#on_weekends"},{"doc":"bg_jobs/scheduled_job","title":"to_bg_jobs_error","content":"pub fn to_bg_jobs_error(date_error: DateError) -&gt; BgJobError\n\nSynonyms:\nbg_jobs/scheduled_job.to_bg_jobs_error\nbg_jobs/scheduled_job to_bg_jobs_error","url":"bg_jobs/scheduled_job.html#to_bg_jobs_error"},{"doc":"bg_jobs/scheduled_job","title":"with_event_listeners","content":"pub fn with_event_listeners(\n  spec: SpecBuilder,\n  event_listeners: List(fn(Event) -&gt; Nil),\n) -&gt; SpecBuilder\n Set event listeners for the queue\n NOTE: This will override previously added workers\n\nSynonyms:\nbg_jobs/scheduled_job.with_event_listeners\nbg_jobs/scheduled_job with_event_listeners","url":"bg_jobs/scheduled_job.html#with_event_listeners"},{"doc":"bg_jobs/scheduled_job","title":"with_init_timeout","content":"pub fn with_init_timeout(\n  spec: SpecBuilder,\n  init_timeout: Int,\n) -&gt; SpecBuilder\n Amount of time in milli seconds the queue is given to start\n\nSynonyms:\nbg_jobs/scheduled_job.with_init_timeout\nbg_jobs/scheduled_job with_init_timeout","url":"bg_jobs/scheduled_job.html#with_init_timeout"},{"doc":"bg_jobs/scheduled_job","title":"with_max_retries","content":"pub fn with_max_retries(\n  spec: SpecBuilder,\n  max_retries: Int,\n) -&gt; SpecBuilder\n Maximum times a job will be retried before being considered failed\n and moved to the failed_jobs table\n\nSynonyms:\nbg_jobs/scheduled_job.with_max_retries\nbg_jobs/scheduled_job with_max_retries","url":"bg_jobs/scheduled_job.html#with_max_retries"},{"doc":"bg_jobs/scheduled_job","title":"with_poll_interval_ms","content":"pub fn with_poll_interval_ms(\n  spec: SpecBuilder,\n  poll_interval: Int,\n) -&gt; SpecBuilder\n Time in milli seconds to wait in between checking for new jobs\n\nSynonyms:\nbg_jobs/scheduled_job.with_poll_interval_ms\nbg_jobs/scheduled_job with_poll_interval_ms","url":"bg_jobs/scheduled_job.html#with_poll_interval_ms"},{"doc":"bg_jobs/scheduled_job","title":"bg_jobs/scheduled_job","content":"","url":"bg_jobs/scheduled_job.html"},{"doc":"bg_jobs","title":"BgJobs","content":"pub type BgJobs {\n  BgJobs(supervisor: process.Pid, enqueue_state: EnqueueState)\n}\n Main type of the library, holds references queues, and scheduled jobs.\n This is then passed as an argument when you want to interact with the background \n jobs in some way, for example enqueueing \n \n ## Example\n \n  let bg = \n   static_supervisor.new(static_supervisor.OneForOne)\n   |&gt; bg_jobs.new(db_adapter)\n  ...\n  |&gt; bg_jobs.build()\n  \n  bg_jobs.new_job(&quot;example_job&quot;, &quot;payload&quot;)\n  |&gt; bg_jobs.enqueue(bg);\n \nBgJobs(supervisor: process.Pid, enqueue_state: EnqueueState)\n\n\nSynonyms:\nbg_jobs.BgJobs\nbg_jobs BgJobs","url":"bg_jobs.html#BgJobs"},{"doc":"bg_jobs","title":"BgJobsBuilder","content":"pub type BgJobsBuilder {\n  BgJobsBuilder(\n    supervisor: sup.Builder,\n    db_adapter: db_adapter.DbAdapter,\n    event_listeners: List(events.EventListener),\n    queues: List(queue.Spec),\n    scheduled_jobs: List(scheduled_job.SpecBuilder),\n  )\n}\n Specification for how the supervisor, queues, scheduled_jobs and \n event_listeners should be setup. It&#39;s built using the builder functions\n ## Example\n \n  let bg = \n   static_supervisor.new(static_supervisor.OneForOne)\n   bg_jobs.new(db_adapter)\n   // Event listeners\n   |&gt; bg_jobs.with_event_listener(logger_event_listener.listner)\n   // Queues\n   |&gt; bg_jobs.with_queue(queue.new(&quot;default_queue&quot;))\n   // Scheduled jobs \n   |&gt; bg_jobs.with_scheduled_job(scheduled_job.new(\n     cleanup_db_job.worker(),\n     scheduled_job.interval_minutes(1),\n   )) \n   |&gt; bg_jobs.build()\n \nBgJobsBuilder(\n  supervisor: sup.Builder,\n  db_adapter: db_adapter.DbAdapter,\n  event_listeners: List(events.EventListener),\n  queues: List(queue.Spec),\n  scheduled_jobs: List(scheduled_job.SpecBuilder),\n)\n\n\nSynonyms:\nbg_jobs.BgJobsBuilder\nbg_jobs BgJobsBuilder","url":"bg_jobs.html#BgJobsBuilder"},{"doc":"bg_jobs","title":"EnqueueState","content":"pub opaque type EnqueueState\n\n\nSynonyms:\nbg_jobs.EnqueueState\nbg_jobs EnqueueState","url":"bg_jobs.html#EnqueueState"},{"doc":"bg_jobs","title":"available_at_from_availability","content":"pub fn available_at_from_availability(\n  availability: JobAvailability,\n) -&gt; #(#(Int, Int, Int), #(Int, Int, Int))\n Convert JobAvailability to erlang date time\n\nSynonyms:\nbg_jobs.available_at_from_availability\nbg_jobs available_at_from_availability","url":"bg_jobs.html#available_at_from_availability"},{"doc":"bg_jobs","title":"build","content":"pub fn build(spec: BgJobsBuilder) -&gt; Result(BgJobs, BgJobError)\n Create the supervisor and all it&#39;s queues based on the provided spec\n\n ## Example\n \n  let bg = \n   static_supervisor.new(static_supervisor.OneForOne)\n     |&gt; bg_jobs.new(db_adapter)\n     ...\n     |&gt; bg_jobs.build()\n\n `\nSynonyms:\nbg_jobs.build\nbg_jobs build","url":"bg_jobs.html#build"},{"doc":"bg_jobs","title":"enqueue","content":"pub fn enqueue(\n  job_request: JobEnqueueRequest,\n  bg: BgJobs,\n) -&gt; Result(Job, BgJobError)\n Enqueues a job for queues to consume when available\n\n ## Example\n \n let bg = \n   static_supervisor.new(static_supervisor.OneForOne)\n   |&gt; bg_jobs.new() |&gt; ... |&gt; bg_jobs.build()\n   |&gt; bg_jobs.new_job(&quot;example_job&quot;, &quot;payload&quot;)\n   |&gt; bg_jobs.enqueue(bg);\n \nSynonyms:\nbg_jobs.enqueue\nbg_jobs enqueue","url":"bg_jobs.html#enqueue"},{"doc":"bg_jobs","title":"job_with_available_at","content":"pub fn job_with_available_at(\n  job_request: JobEnqueueRequest,\n  availabile_at: #(#(Int, Int, Int), #(Int, Int, Int)),\n) -&gt; JobEnqueueRequest\n Set the availability to a specific time in the future\n\nSynonyms:\nbg_jobs.job_with_available_at\nbg_jobs job_with_available_at","url":"bg_jobs.html#job_with_available_at"},{"doc":"bg_jobs","title":"job_with_available_in","content":"pub fn job_with_available_in(\n  job_request: JobEnqueueRequest,\n  availabile_in: Int,\n) -&gt; JobEnqueueRequest\n Set the availability to a relative time in the future\n\nSynonyms:\nbg_jobs.job_with_available_in\nbg_jobs job_with_available_in","url":"bg_jobs.html#job_with_available_in"},{"doc":"bg_jobs","title":"new","content":"pub fn new(\n  supervisor: Builder,\n  db_adapter: DbAdapter,\n) -&gt; BgJobsBuilder\n Create a new default BgJobsBuilder\n\n ## Example\n \n  let bg = \n   static_supervisor.new(static_supervisor.OneForOne)\n   bg_jobs.new(db_adapter)\n \nSynonyms:\nbg_jobs.new\nbg_jobs new","url":"bg_jobs.html#new"},{"doc":"bg_jobs","title":"new_job","content":"pub fn new_job(\n  name: String,\n  payload: String,\n) -&gt; JobEnqueueRequest\n Create a new job request that can be enqueued\n\nSynonyms:\nbg_jobs.new_job\nbg_jobs new_job","url":"bg_jobs.html#new_job"},{"doc":"bg_jobs","title":"with_event_listener","content":"pub fn with_event_listener(\n  spec: BgJobsBuilder,\n  event_listener: fn(Event) -&gt; Nil,\n) -&gt; BgJobsBuilder\n Add an event_listener to all queues under the supervisor\n\n ## Example\n \n  let bg = \n    static_supervisor.new(static_supervisor.OneForOne)\n    |&gt; bg_jobs.new(db_adapter)\n    |&gt; with_event_listener(logger_event_listener.listener)\n \nSynonyms:\nbg_jobs.with_event_listener\nbg_jobs with_event_listener","url":"bg_jobs.html#with_event_listener"},{"doc":"bg_jobs","title":"with_queue","content":"pub fn with_queue(\n  spec: BgJobsBuilder,\n  queue: Spec,\n) -&gt; BgJobsBuilder\n Add a queue-spec to create a new queue with the supervisor\n\n ## Example\n \n  let bg = \n   static_supervisor.new(static_supervisor.OneForOne)\n   |&gt; bg_jobs.new(db_adapter)\n   |&gt; with_queue(queue.new(&quot;example_queue&quot;) |&gt; queue.add_worker(example_worker))\n \nSynonyms:\nbg_jobs.with_queue\nbg_jobs with_queue","url":"bg_jobs.html#with_queue"},{"doc":"bg_jobs","title":"with_scheduled_job","content":"pub fn with_scheduled_job(\n  spec: BgJobsBuilder,\n  scheduled_job: SpecBuilder,\n) -&gt; BgJobsBuilder\n Add a scheduled job spec to create a new queue with the supervisor\n\n ## Example\n \n  let bg = \n   static_supervisor.new(static_supervisor.OneForOne)\n   |&gt; bg_jobs.new(db_adapter)\n   |&gt; with_scheduled_job(scheduled_job.new(\n     example_worker, \n     scheduled_job.interval_minutes(1)\n   ))\n \nSynonyms:\nbg_jobs.with_scheduled_job\nbg_jobs with_scheduled_job","url":"bg_jobs.html#with_scheduled_job"},{"doc":"bg_jobs","title":"bg_jobs","content":"","url":"bg_jobs.html"},{"doc":"bg_jobs/logger_event_listener","title":"listner","content":"pub fn listner(event: Event) -&gt; Nil\n Listen to events and logg them using the [logging](https://hexdocs.pm/logging/) library\n\nSynonyms:\nbg_jobs/logger_event_listener.listner\nbg_jobs/logger_event_listener listner","url":"bg_jobs/logger_event_listener.html#listner"},{"doc":"bg_jobs/logger_event_listener","title":"bg_jobs/logger_event_listener","content":"","url":"bg_jobs/logger_event_listener.html"},{"doc":"bg_jobs/postgres_db_adapter","title":"new","content":"pub fn new(\n  conn: Connection,\n  event_listners: List(fn(Event) -&gt; Nil),\n) -&gt; DbAdapter\n Create a new postgres_db_adapter\n\nSynonyms:\nbg_jobs/postgres_db_adapter.new\nbg_jobs/postgres_db_adapter new","url":"bg_jobs/postgres_db_adapter.html#new"},{"doc":"bg_jobs/postgres_db_adapter","title":"bg_jobs/postgres_db_adapter","content":"","url":"bg_jobs/postgres_db_adapter.html"},{"doc":"bg_jobs/sqlite_db_adapter","title":"new","content":"pub fn new(\n  conn: Connection,\n  event_listners: List(fn(Event) -&gt; Nil),\n) -&gt; DbAdapter\n Create a new sqlite_db_adapter\n \nSynonyms:\nbg_jobs/sqlite_db_adapter.new\nbg_jobs/sqlite_db_adapter new","url":"bg_jobs/sqlite_db_adapter.html#new"},{"doc":"bg_jobs/sqlite_db_adapter","title":"bg_jobs/sqlite_db_adapter","content":"","url":"bg_jobs/sqlite_db_adapter.html"}]);